Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(517)

Unified Diff: content/browser/service_worker/service_worker_navigation_handle_core.h

Issue 2460223003: Support Service Worker NavigationPreload with PlzNavigate. (Closed)
Patch Set: fix windows compile error Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_navigation_handle_core.h
diff --git a/content/browser/service_worker/service_worker_navigation_handle_core.h b/content/browser/service_worker/service_worker_navigation_handle_core.h
index 88e5013c9d20ac5fb2b5d735023f84eab912e250..0fb22e9ec434f5a56dd690dd54325ba925da0ad9 100644
--- a/content/browser/service_worker/service_worker_navigation_handle_core.h
+++ b/content/browser/service_worker/service_worker_navigation_handle_core.h
@@ -13,22 +13,25 @@
namespace content {
+class ResourceMessageFilter;
class ServiceWorkerContextWrapper;
class ServiceWorkerNavigationHandle;
class ServiceWorkerProviderHost;
// PlzNavigate
// This class is used to manage the lifetime of ServiceWorkerProviderHosts
// created during navigations. This class is created on the UI thread, but
// should only be accessed from the IO thread afterwards. It is the IO thread
// pendant of ServiceWorkerNavigationHandle. See the
// ServiceWorkerNavigationHandle header for more details about the lifetime of
// both classes.
class ServiceWorkerNavigationHandleCore {
public:
ServiceWorkerNavigationHandleCore(
base::WeakPtr<ServiceWorkerNavigationHandle> ui_handle,
- ServiceWorkerContextWrapper* context_wrapper);
+ ServiceWorkerContextWrapper* context_wrapper,
+ ResourceMessageFilter* resource_message_filter);
~ServiceWorkerNavigationHandleCore();
// Called when a ServiceWorkerProviderHost was pre-created for the navigation
@@ -48,6 +51,7 @@ class ServiceWorkerNavigationHandleCore {
private:
std::unique_ptr<ServiceWorkerProviderHost> precreated_host_;
scoped_refptr<ServiceWorkerContextWrapper> context_wrapper_;
+ scoped_refptr<ResourceMessageFilter> resource_message_filter_;
base::WeakPtr<ServiceWorkerNavigationHandle> ui_handle_;
DISALLOW_COPY_AND_ASSIGN(ServiceWorkerNavigationHandleCore);
@@ -13,22 +13,25 @@
// PlzNavigate
// This class is used to manage the lifetime of ServiceWorkerProviderHosts
-// created during navigations. This class is created on the UI thread, but
-// should only be accessed from the IO thread afterwards. It is the IO thread
-// pendant of ServiceWorkerNavigationHandle. See the
-// ServiceWorkerNavigationHandle header for more details about the lifetime of
-// both classes.
+// created during navigations. And also it is used to pass the pointer of
+// ResourceMessageFilter for navigation preload from the UI thread to the IO
+// thread. This class is created on the UI thread, but should only be accessed
+// from the IO thread afterwards. It is the IO thread pendant of
+// ServiceWorkerNavigationHandle. See the ServiceWorkerNavigationHandle header
+// for more details about the lifetime of both classes.
class ServiceWorkerNavigationHandleCore {
public:

Powered by Google App Engine
This is Rietveld 408576698